@@ -3,6 +3,8 @@
 # email:yuyc@ishangqi.com
 # date:2021/11/26 3:56 下午
 # Copyright (C) 2021 The lesscode Team
+import asyncio
+from asyncio import events
 
 from tornado.options import options
 
@@ -99,3 +101,39 @@ class DSHelper(BaseSqlHelper):
 
     def prepare_page_sql(self, condition_wrapper: ConditionWrapper, page_num: int, page_size: int):
         return self.db_helper.prepare_page_sql(condition_wrapper, page_num, page_size)
+
+    def sync_insert_data(self, table_name: str, data):
+        return self.db_helper.sync_insert_data(table_name, data)
+
+    def sync_insert_one_data(self, table_name: str, data: dict):
+        return self.db_helper.sync_insert_one_data(table_name, data)
+
+    def sync_insert_many_data(self, table_name: str, data: list):
+        return self.db_helper.sync_insert_many_data(table_name, data)
+
+    def sync_update_data(self, condition_wrapper: ConditionWrapper, param: dict):
+        return self.db_helper.sync_update_data(condition_wrapper, param)
+
+    def sync_delete_data(self, condition_wrapper: ConditionWrapper):
+        return self.db_helper.sync_delete_data(condition_wrapper)
+
+    def sync_fetchone_data(self, condition_wrapper: ConditionWrapper):
+        return self.db_helper.sync_fetchone_data(condition_wrapper)
+
+    def sync_fetchall_data(self, condition_wrapper: ConditionWrapper):
+        return self.db_helper.sync_fetchall_data(condition_wrapper)
+
+    def sync_fetchall_page(self, condition_wrapper: ConditionWrapper, page_num=1, page_size=10):
+        return self.db_helper.sync_fetchall_page(condition_wrapper, page_num, page_size)
+
+    def sync_execute_sql(self, sql: str, param=None):
+        return self.db_helper.sync_execute_sql(sql, param)
+
+    def sync_executemany_sql(self, sql: str, param=None):
+        return self.db_helper.sync_executemany_sql(sql, param)
+
+    def sync_execute_fetchone(self, sql: str, param=None):
+        return self.db_helper.sync_execute_fetchone(sql, param)
+
+    def sync_execute_fetchall(self, sql: str, param=None):
+        return self.db_helper.sync_execute_fetchall(sql, param)
