@@ -85,7 +85,7 @@ def Handler(url: str, desc=""):
     return wrapper
 
 
-def GetMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1,
+def GetMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: int = 1,
                interface_desc: str = ""):
     """
     用于类名、处理方法、url 的元祖集合注册处理，暂时GetMapping与PostMapping实现保持一致，预留入口为后期扩展提供支持。
@@ -115,7 +115,7 @@ def GetMapping(url: str = "", client_name: str = None, title: str = None, en_nam
     return wrapper
 
 
-def PostMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1,
+def PostMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: int = 1,
                 interface_desc: str = ""):
     """
     用于类名、处理方法、url 的元祖集合注册处理，暂时GetMapping与PostMapping实现保持一致，预留入口为后期扩展提供支持。
